<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Regular News Pro
 * @since Regular News Pro 1.0.0
 * @return array An array of default values
 */

function regular_news_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$regular_news_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#212121',
		'header_tagline_color'			=> '#212121',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff4443',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'regular-news-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'regular-news-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'regular-news-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'regular-news-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'headline,popular,featured,cta,recent,featured_video,blog,must_read',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'regular-news-pro' ),
		'hide_category'					=> false,
		'hide_author'					=> false,
		'hide_date'						=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Topbar
		'topbar_section_enable'			=> false,
		'secondary_menu_enable'			=> false,
		'social_menu_enable'			=> false,

		// Headline
		'headline_section_enable'		=> true,
		'headline_content_type'			=> 'category',
		'headline_count'				=> 5,
		'headline_title'				=> esc_html__( 'Breaking News', 'regular-news-pro' ),

		// Hero
		'popular_section_enable'		=> true,
		'popular_content_type'			=> 'category',
		'popular_count'					=> 5,

		// Featured
		'featured_section_enable'		=> true,
		'featured_title'				=> esc_html__( 'Featured Articles', 'regular-news-pro' ),
		'featured_content_type'			=> 'category',
		'featured_count'				=> 5,

		// call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_title'						=> esc_html__( 'How to Set Up a Beautiful Shopify Store With the Parallax Theme', 'regular-news-pro' ),
		'cta_btn_title'					=> esc_html__( 'Contact Us', 'regular-news-pro' ),

		// Trending
		'recent_section_enable'			=> true,
		'recent_title'					=> esc_html__( 'Technology', 'regular-news-pro' ),

		// Featured Video
		'featured_video_section_enable'	=> true,
		'featured_video_title'			=> esc_html__( 'Featured Videos', 'regular-news-pro' ),
		'featured_video_content_type'	=> 'category',
		'featured_video_count'			=> 5,

		// Must Read
		'must_read_section_enable'		=> true,
		'must_read_title'				=> esc_html__( 'Must Read Articles', 'regular-news-pro' ),
		'must_read_content_type'			=> 'category',
		'must_read_count'				=> 4,

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_readmore_title'			=> esc_html__( 'Read More', 'regular-news-pro' ),
		'blog_title'					=> esc_html__( 'Recently Viewed', 'regular-news-pro' ),
		'blog_btn_title'				=> esc_html__( 'Show All', 'regular-news-pro' ),

	);

	$output = apply_filters( 'regular_news_pro_default_theme_options', $regular_news_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}