<?php
/**
 * Featured Video Section options
 *
 * @package Theme Palace
 * @subpackage Regular News Pro
 * @since Regular News Pro 1.0.0
 */

// Add Featured Video section
$wp_customize->add_section( 'regular_news_pro_featured_video_section', array(
	'title'             => esc_html__( 'Featured Video','regular-news-pro' ),
	'description'       => esc_html__( 'Featured Video Section options.', 'regular-news-pro' ),
	'panel'             => 'regular_news_pro_front_page_panel',
) );

// Featured Video content enable control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_section_enable]', array(
	'default'			=> 	$options['featured_video_section_enable'],
	'sanitize_callback' => 'regular_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Regular_News_Pro_Switch_Control( $wp_customize, 'regular_news_pro_theme_options[featured_video_section_enable]', array(
	'label'             => esc_html__( 'Featured Video Section Enable', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_featured_video_section',
	'on_off_label' 		=> regular_news_pro_switch_options(),
) ) );

// featured_video title setting and control
$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_video_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'regular_news_pro_theme_options[featured_video_title]', array(
	'label'           	=> esc_html__( 'Title', 'regular-news-pro' ),
	'section'        	=> 'regular_news_pro_featured_video_section',
	'active_callback' 	=> 'regular_news_pro_is_featured_video_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'regular_news_pro_theme_options[featured_video_title]', array(
		'selector'            => '#featured-videos .section-header h2',
		'settings'            => 'regular_news_pro_theme_options[featured_video_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'regular_news_pro_featured_video_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_count]', array(
	'default'          	=> $options['featured_video_count'],
	'sanitize_callback' => 'regular_news_pro_sanitize_number_range',
	'validate_callback' => 'regular_news_pro_validate_featured_video_count',
) );

$wp_customize->add_control( 'regular_news_pro_theme_options[featured_video_count]', array(
	'label'             => esc_html__( 'Number of page/post', 'regular-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_featured_video_section',
	'active_callback'   => 'regular_news_pro_is_featured_video_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Portfolio content type control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_content_type]', array(
	'default'          	=> $options['featured_video_content_type'],
	'sanitize_callback' => 'regular_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'regular_news_pro_theme_options[featured_video_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'regular-news-pro' ),
	'description'       => esc_html__( 'Note: Video input field is not available in recent and category content type option.', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_featured_video_section',
	'type'				=> 'select',
	'active_callback' 	=> 'regular_news_pro_is_featured_video_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'regular-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'regular-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'regular-news-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'regular-news-pro' ),
	),
) );

for ( $i = 1; $i <= $options['featured_video_count']; $i++ ) {
	// featured_video pages drop down chooser control and setting
	$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_content_page_' . $i . ']', array(
		'sanitize_callback' => 'regular_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Regular_News_Pro_Dropdown_Chooser( $wp_customize, 'regular_news_pro_theme_options[featured_video_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'regular-news-pro' ), $i ),
		'section'           => 'regular_news_pro_featured_video_section',
		'choices'			=> regular_news_pro_page_choices(),
		'active_callback'	=> 'regular_news_pro_is_featured_video_section_content_page_enable',
	) ) );

	// featured_video posts drop down chooser control and setting
	$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_content_post_' . $i . ']', array(
		'sanitize_callback' => 'regular_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Regular_News_Pro_Dropdown_Chooser( $wp_customize, 'regular_news_pro_theme_options[featured_video_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'regular-news-pro' ), $i ),
		'section'           => 'regular_news_pro_featured_video_section',
		'choices'			=> regular_news_pro_post_choices(),
		'active_callback'	=> 'regular_news_pro_is_featured_video_section_content_post_enable',
	) ) );

	// featured_video title setting and control
	$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'regular_news_pro_theme_options[featured_video_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'regular-news-pro' ), $i ),
		'section'        	=> 'regular_news_pro_featured_video_section',
		'active_callback' 	=> 'regular_news_pro_is_featured_video_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// featured_video link setting and control
	$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_title_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'regular_news_pro_theme_options[featured_video_title_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( ' Title Link %d', 'regular-news-pro' ), $i ),
		'section'        	=> 'regular_news_pro_featured_video_section',
		'active_callback' 	=> 'regular_news_pro_is_featured_video_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// featured_video image setting and control.
	$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_image_' . $i . ']', array(
		'sanitize_callback' => 'regular_news_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'regular_news_pro_theme_options[featured_video_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'regular-news-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'regular-news-pro' ), 587, 775 ),
			'section'     		=> 'regular_news_pro_featured_video_section',
			'active_callback'	=> 'regular_news_pro_is_featured_video_section_content_custom_enable',
	) ) );

	// featured_video video link setting and control
	$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'regular_news_pro_theme_options[featured_video_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Video Link %d', 'regular-news-pro' ), $i ),
		'description'       => sprintf( esc_html__( 'You can insert YouTube or Vimeo video url.', 'regular-news-pro' ), $i ),
		'section'        	=> 'regular_news_pro_featured_video_section',
		'active_callback' 	=> 'regular_news_pro_is_featured_video_section_video_enable',
		'type'				=> 'url',
	) );

	// featured_video hr control and setting
	$wp_customize->add_setting( 'regular_news_pro_theme_options[featured_video_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Regular_News_Pro_Customize_Horizontal_Line( $wp_customize, 'regular_news_pro_theme_options[featured_video_hr_' . $i . ']', array(
		'section'           => 'regular_news_pro_featured_video_section',
		'active_callback'	=> 'regular_news_pro_is_featured_video_section_video_enable',
		'type'			    => 'hr'
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'regular_news_pro_theme_options[featured_video_content_category]', array(
	'sanitize_callback' => 'regular_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Regular_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'regular_news_pro_theme_options[featured_video_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'regular-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_featured_video_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'regular_news_pro_is_featured_video_section_content_category_enable'
) ) );
