<?php
/**
 * Must Read Section options
 *
 * @package Theme Palace
 * @subpackage Regular News Pro
 * @since Regular News Pro 1.0.0
 */

// Add Must Read section
$wp_customize->add_section( 'regular_news_pro_must_read_section', array(
	'title'             => esc_html__( 'Must Read','regular-news-pro' ),
	'description'       => esc_html__( 'Must Read Section options.', 'regular-news-pro' ),
	'panel'             => 'regular_news_pro_front_page_panel',
) );

// Must Read content enable control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[must_read_section_enable]', array(
	'default'			=> 	$options['must_read_section_enable'],
	'sanitize_callback' => 'regular_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Regular_News_Pro_Switch_Control( $wp_customize, 'regular_news_pro_theme_options[must_read_section_enable]', array(
	'label'             => esc_html__( 'Must Read Section Enable', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_must_read_section',
	'on_off_label' 		=> regular_news_pro_switch_options(),
) ) );

// must_read title setting and control
$wp_customize->add_setting( 'regular_news_pro_theme_options[must_read_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['must_read_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'regular_news_pro_theme_options[must_read_title]', array(
	'label'           	=> esc_html__( 'Title', 'regular-news-pro' ),
	'section'        	=> 'regular_news_pro_must_read_section',
	'active_callback' 	=> 'regular_news_pro_is_must_read_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'regular_news_pro_theme_options[must_read_title]', array(
		'selector'            => '#must-read .section-header h2',
		'settings'            => 'regular_news_pro_theme_options[must_read_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'regular_news_pro_must_read_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[must_read_count]', array(
	'default'          	=> $options['must_read_count'],
	'sanitize_callback' => 'regular_news_pro_sanitize_number_range',
	'validate_callback' => 'regular_news_pro_validate_must_read_count',
) );

$wp_customize->add_control( 'regular_news_pro_theme_options[must_read_count]', array(
	'label'             => esc_html__( 'Number of page/post', 'regular-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_must_read_section',
	'active_callback'   => 'regular_news_pro_is_must_read_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

// Hero content type control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[must_read_content_type]', array(
	'default'          	=> $options['must_read_content_type'],
	'sanitize_callback' => 'regular_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'regular_news_pro_theme_options[must_read_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_must_read_section',
	'type'				=> 'select',
	'active_callback' 	=> 'regular_news_pro_is_must_read_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'regular-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'regular-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'regular-news-pro' ),
	),
) );

for ( $i = 1; $i <= $options['must_read_count']; $i++ ) :
	// must_read pages drop down chooser control and setting
	$wp_customize->add_setting( 'regular_news_pro_theme_options[must_read_content_page_' . $i . ']', array(
		'sanitize_callback' => 'regular_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Regular_News_Pro_Dropdown_Chooser( $wp_customize, 'regular_news_pro_theme_options[must_read_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'regular-news-pro' ), $i ),
		'section'           => 'regular_news_pro_must_read_section',
		'choices'			=> regular_news_pro_page_choices(),
		'active_callback'	=> 'regular_news_pro_is_must_read_section_content_page_enable',
	) ) );

	// must_read posts drop down chooser control and setting
	$wp_customize->add_setting( 'regular_news_pro_theme_options[must_read_content_post_' . $i . ']', array(
		'sanitize_callback' => 'regular_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Regular_News_Pro_Dropdown_Chooser( $wp_customize, 'regular_news_pro_theme_options[must_read_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'regular-news-pro' ), $i ),
		'section'           => 'regular_news_pro_must_read_section',
		'choices'			=> regular_news_pro_post_choices(),
		'active_callback'	=> 'regular_news_pro_is_must_read_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'regular_news_pro_theme_options[must_read_content_category]', array(
	'sanitize_callback' => 'regular_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Regular_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'regular_news_pro_theme_options[must_read_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'regular-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_must_read_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'regular_news_pro_is_must_read_section_content_category_enable'
) ) );
