<?php
/**
 * Popular Section options
 *
 * @package Theme Palace
 * @subpackage Regular News Pro
 * @since Regular News Pro 1.0.0
 */

// Add Popular section
$wp_customize->add_section( 'regular_news_pro_popular_section', array(
	'title'             => esc_html__( 'Popular Section','regular-news-pro' ),
	'description'       => esc_html__( 'Popular Section options.', 'regular-news-pro' ),
	'panel'             => 'regular_news_pro_front_page_panel',
) );

// Popular content enable control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[popular_section_enable]', array(
	'default'			=> 	$options['popular_section_enable'],
	'sanitize_callback' => 'regular_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Regular_News_Pro_Switch_Control( $wp_customize, 'regular_news_pro_theme_options[popular_section_enable]', array(
	'label'             => esc_html__( 'Popular Section Enable', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_popular_section',
	'on_off_label' 		=> regular_news_pro_switch_options(),
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[popular_count]', array(
	'default'          	=> $options['popular_count'],
	'sanitize_callback' => 'regular_news_pro_sanitize_number_range',
	'validate_callback' => 'regular_news_pro_validate_popular_count',
) );

$wp_customize->add_control( 'regular_news_pro_theme_options[popular_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'regular-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_popular_section',
	'active_callback'   => 'regular_news_pro_is_popular_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Popular content type control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[popular_content_type]', array(
	'default'          	=> $options['popular_content_type'],
	'sanitize_callback' => 'regular_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'regular_news_pro_theme_options[popular_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_popular_section',
	'type'				=> 'select',
	'active_callback' 	=> 'regular_news_pro_is_popular_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'regular-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'regular-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'regular-news-pro' ),
	),
) );

for ( $i = 1; $i <= $options['popular_count']; $i++ ) :
	// popular pages drop down chooser control and setting
	$wp_customize->add_setting( 'regular_news_pro_theme_options[popular_content_page_' . $i . ']', array(
		'sanitize_callback' => 'regular_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Regular_News_Pro_Dropdown_Chooser( $wp_customize, 'regular_news_pro_theme_options[popular_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'regular-news-pro' ), $i ),
		'section'           => 'regular_news_pro_popular_section',
		'choices'			=> regular_news_pro_page_choices(),
		'active_callback'	=> 'regular_news_pro_is_popular_section_content_page_enable',
	) ) );

	// popular posts drop down chooser control and setting
	$wp_customize->add_setting( 'regular_news_pro_theme_options[popular_content_post_' . $i . ']', array(
		'sanitize_callback' => 'regular_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Regular_News_Pro_Dropdown_Chooser( $wp_customize, 'regular_news_pro_theme_options[popular_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'regular-news-pro' ), $i ),
		'section'           => 'regular_news_pro_popular_section',
		'choices'			=> regular_news_pro_post_choices(),
		'active_callback'	=> 'regular_news_pro_is_popular_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'regular_news_pro_theme_options[popular_content_category]', array(
	'sanitize_callback' => 'regular_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Regular_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'regular_news_pro_theme_options[popular_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'regular-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_popular_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'regular_news_pro_is_popular_section_content_category_enable'
) ) );
