<?php
/**
 * Recent Post Section options
 *
 * @package Theme Palace
 * @subpackage Regular News Pro
 * @since Regular News Pro 1.0.0
 */

// Add Recent Post section
$wp_customize->add_section( 'regular_news_pro_recent_section', array(
	'title'             => esc_html__( 'Recent Post','regular-news-pro' ),
	'description'       => esc_html__( 'Recent Post Section options.', 'regular-news-pro' ),
	'panel'             => 'regular_news_pro_front_page_panel',
) );

// Recent Post content enable control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[recent_section_enable]', array(
	'default'			=> 	$options['recent_section_enable'],
	'sanitize_callback' => 'regular_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Regular_News_Pro_Switch_Control( $wp_customize, 'regular_news_pro_theme_options[recent_section_enable]', array(
	'label'             => esc_html__( 'Recent Post Section Enable', 'regular-news-pro' ),
	'section'           => 'regular_news_pro_recent_section',
	'on_off_label' 		=> regular_news_pro_switch_options(),
) ) );

// recent title setting and control
$wp_customize->add_setting( 'regular_news_pro_theme_options[recent_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'regular_news_pro_theme_options[recent_title]', array(
	'label'           	=> esc_html__( 'Title', 'regular-news-pro' ),
	'section'        	=> 'regular_news_pro_recent_section',
	'active_callback' 	=> 'regular_news_pro_is_recent_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'regular_news_pro_theme_options[recent_title]', array(
		'selector'            => '#recent-posts .section-header-wrapper .section-header h2.section-title',
		'settings'            => 'regular_news_pro_theme_options[recent_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'regular_news_pro_recent_title_partial',
    ) );
}

// recent posts drop down chooser control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[recent_categories]', array(
	'sanitize_callback' => 'regular_news_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Regular_News_Pro_Dropdown_Multiple_Chooser( $wp_customize, 'regular_news_pro_theme_options[recent_categories]', array(
	'label'             => esc_html__( 'Select Multiple Tab Categories', 'regular-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest five posts will be shown from each selected category', 'regular-news-pro' ),
	'type'           	=> 'dropdown_multiple_chooser',
	'choices'			=> 	regular_news_pro_category_choices(),
	'section'           => 'regular_news_pro_recent_section',
	'active_callback'	=> 'regular_news_pro_is_recent_section_enable',
) ) );

// recent posts drop down chooser control and setting
$wp_customize->add_setting( 'regular_news_pro_theme_options[recent_grid_categories]', array(
	'sanitize_callback' => 'regular_news_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Regular_News_Pro_Dropdown_Multiple_Chooser( $wp_customize, 'regular_news_pro_theme_options[recent_grid_categories]', array(
	'label'             => esc_html__( 'Select Multiple Grid Categories Categories', 'regular-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest five posts will be shown from each selected category', 'regular-news-pro' ),
	'type'           	=> 'dropdown_multiple_chooser',
	'choices'			=> 	regular_news_pro_category_choices(),
	'section'           => 'regular_news_pro_recent_section',
	'active_callback'	=> 'regular_news_pro_is_recent_section_enable',
) ) );

