<?php
/**
 * Featured Video section
 *
 * This is the template for the content of featured_video section
 *
 * @package Theme Palace
 * @subpackage Regular News Pro
 * @since Regular News Pro 1.0.0
 */
if ( ! function_exists( 'regular_news_pro_add_featured_video_section' ) ) :
    /**
    * Add featured_video section
    *
    *@since Regular News Pro 1.0.0
    */
    function regular_news_pro_add_featured_video_section() {
        $options = regular_news_pro_get_theme_options();
        // Check if featured_video is enabled on frontpage
        $featured_video_enable = apply_filters( 'regular_news_pro_section_status', true, 'featured_video_section_enable' );

        if ( true !== $featured_video_enable ) {
            return false;
        }
        // Get featured_video section details
        $section_details = array();
        $section_details = apply_filters( 'regular_news_pro_filter_featured_video_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_video section now.
        regular_news_pro_render_featured_video_section( $section_details );
    }
endif;

if ( ! function_exists( 'regular_news_pro_get_featured_video_section_details' ) ) :
    /**
    * featured_video section details.
    *
    * @since Regular News Pro 1.0.0
    * @param array $input featured_video section details.
    */
    function regular_news_pro_get_featured_video_section_details( $input ) {
        $options = regular_news_pro_get_theme_options();

        // Content type.
        $featured_video_content_type  = $options['featured_video_content_type'];
        $featured_video_count = ! empty( $options['featured_video_count'] ) ? $options['featured_video_count'] : 5;
        
        $content = array();
        switch ( $featured_video_content_type ) {
            
            case 'page':
                $page_ids = array();
       
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_video_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
          
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_video_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_video_content_category'] ) ? $options['featured_video_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_video_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $featured_video_count; $i++ ) {
                    $custom['id']           = $i;
                    $custom['title']        = ! empty( $options['featured_video_title_' . $i] ) ? $options['featured_video_title_' . $i] : '';
                    $custom['image']        = ! empty( $options['featured_video_image_' . $i] ) ? $options['featured_video_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-400x250.jpg';
                    $custom['url']          = ! empty( $options['featured_video_title_link_' . $i] ) ? $options['featured_video_title_link_' . $i] : '#';
                    $custom['video']        = ! empty( $options['featured_video_link_' . $i] ) ? $options['featured_video_link_' . $i] : '';

                    // Push to the main array.
                    array_push( $content, $custom );
                }

            default:
            break;
        }


        if ( 'custom' !== $featured_video_content_type ) :

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $i = 1; 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['auth_id']   = get_the_author_meta('ID');
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    if ( ! in_array( $featured_video_content_type, array('category' ) ) ) {
                        $page_post['video'] = ! empty( $options['featured_video_link_' . $i] ) ? $options['featured_video_link_' . $i] : '';
                    }
                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_video section content details.
add_filter( 'regular_news_pro_filter_featured_video_section_details', 'regular_news_pro_get_featured_video_section_details' );


if ( ! function_exists( 'regular_news_pro_render_featured_video_section' ) ) :
  /**
   * Start featured_video section
   *
   * @return string featured_video content
   * @since Regular News Pro 1.0.0
   *
   */
   function regular_news_pro_render_featured_video_section( $content_details = array() ) {
        $options = regular_news_pro_get_theme_options();
        $featured_video_content_type  = $options['featured_video_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>


        <div id="featured-videos" class="page-section">
                <div class="wrapper">
                    <?php if ( ! empty( $options['featured_video_title'] ) ) : ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['featured_video_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="section-content grid">
                       
                        <?php $i=0; foreach ( $content_details as $content ) : ?>
                            <article class="grid-item large-width <?php echo ($i == 7) ? 'reverse' : ''; ?>">
                                <div class="grid-wrapper"> 
                                     <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                        <div class="overlay"></div>
                                    </div>

                                    <div class="entry-container">
                                        <?php if ( ! in_array( $featured_video_content_type, array( 'category' ) ) && ! empty( $content['video'] ) ) : ?>
                                            <a href="<?php echo esc_url( $content['video'] ); ?>" class="video-link">
                                                <?php  echo regular_news_pro_get_svg( array( 'icon' => 'play' ) ); ?>
                                            </a>
                                        <?php endif; 

                                        if ( $featured_video_content_type !== 'custom' ) : ?>
                                            <div class="entry-meta">
                                                 <?php  
                                                    echo regular_news_pro_author( $content['auth_id'] );
                                                    regular_news_pro_posted_on( $content['id'] );
                                                ?>
               
                                            </div><!-- .entry-meta -->
                                        <?php endif; 

                                        if ( ! empty( $content['title'] ) ) : ?>
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>" tabindex="0"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>
                                        <?php endif; ?>

                                        <?php if ( ! in_array( $featured_video_content_type, array( 'custom' , 'page' ) ) )  : ?>
                                            <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span><!-- .cat-links -->
                                        <?php endif; ?> 
                                    </div><!-- .entry-container -->
                                </div><!-- .grid-wrapper -->
                            </article><!-- .hentry -->
                        <?php $i++; endforeach; ?>
                    </div>
                </div>

                <?php  foreach ( $content_details as $content ) : ?>
                    <?php if ( ! in_array( $featured_video_content_type, array( 'category' ) ) && ! empty( $content['video'] ) ) : ?>
                        <div class="video-overlay"></div>
                        <div class="popup">
                            <div class="widget widget_media_video">
                                <?php echo do_shortcode( '[video src="' . esc_url( $content['video'] ) . '"]' ); ?>
                            </div>
                        </div><!-- .popup -->
                    <?php endif; ?>
                <?php endforeach; ?>
        
        </div><!-- #featured-videos -->
    <?php }
endif;
