<?php
/**
 * Featured Article section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage Regular News Pro
 * @since Regular News Pro 1.0.0
 */
if ( ! function_exists( 'regular_news_pro_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since Regular News Pro 1.0.0
    */
    function regular_news_pro_add_featured_section() {
        $options = regular_news_pro_get_theme_options();
        // Check if featured is enabled on frontpage
        $featured_enable = apply_filters( 'regular_news_pro_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get featured section details
        $section_details = array();
        $section_details = apply_filters( 'regular_news_pro_filter_featured_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured section now.
        regular_news_pro_render_featured_section( $section_details );
    }
endif;

if ( ! function_exists( 'regular_news_pro_get_featured_section_details' ) ) :
    /**
    * featured section details.
    *
    * @since Regular News Pro 1.0.0
    * @param array $input featured section details.
    */
    function regular_news_pro_get_featured_section_details( $input ) {
        $options = regular_news_pro_get_theme_options();

        // Content type.
        $featured_content_type  = $options['featured_content_type'];
        $featured_count = ! empty( $options['featured_count'] ) ? $options['featured_count'] : 5;
        
        $content = array();
        switch ( $featured_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_count; $i++ ) {
                    if ( ! empty( $options['featured_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['auth_id']   = get_the_author_meta('ID');
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = regular_news_pro_trim_content( 25 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured section content details.
add_filter( 'regular_news_pro_filter_featured_section_details', 'regular_news_pro_get_featured_section_details' );


if ( ! function_exists( 'regular_news_pro_render_featured_section' ) ) :
  /**
   * Start featured section
   *
   * @return string featured content
   * @since Regular News Pro 1.0.0
   *
   */
   function regular_news_pro_render_featured_section( $content_details = array() ) {
        $options = regular_news_pro_get_theme_options();
        $featured_content_type  = $options['featured_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="featured-posts" class="relative page-section">
                <div class="wrapper">

                    <?php if ( ! empty( $options['featured_title'] ) ) : ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['featured_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="hero-section-wrapper item-wrapper grid">
                        <?php 
                            $i =1;
                            foreach ( $content_details as $content ) : 
                        ?>
                            <article class="grid-item <?php echo ($i ==1) ? 'large-width' : '' ; ?>"> 
                                <div class="featured-post-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                    </div>
                                    <div class="entry-container">
                                        <div class="entry-meta">
                                             <?php  
                                                echo regular_news_pro_author( $content['auth_id'] );
                                                regular_news_pro_posted_on( $content['id'] );
                                            ?>
               
                                        </div><!-- .entry-meta -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>" tabindex="0"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div>

                                        <?php if ( $featured_content_type !== 'page' ) : ?>
                                            <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span><!-- .cat-links -->
                                        <?php endif; ?>  
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-post-wrapper -->
                            </article><!-- .hentry -->
                        <?php 
                        $i++;
                        ($i == 6) ? $i =1 : $i;
                        endforeach; ?>
                    </div>

                </div><!-- .wrapper -->
            </div><!-- #featured-posts -->
        
    <?php }
endif;
