<?php
/**
 * Trending section
 *
 * This is the template for the content of recent section
 *
 * @package Theme Palace
 * @subpackage Regular News Pro
 * @since Regular News Pro 1.0.0
 */
if ( ! function_exists( 'regular_news_pro_add_recent_section' ) ) :
    /**
    * Add recent section
    *
    *@since Regular News Pro 1.0.0
    */
    function regular_news_pro_add_recent_section() {
        $options = regular_news_pro_get_theme_options();
        // Check if recent is enabled on frontpage
        $recent_enable = apply_filters( 'regular_news_pro_section_status', true, 'recent_section_enable' );

        if ( true !== $recent_enable ) {
            return false;
        }
        // Get recent section details
        $section_details = array();
        $section_details = apply_filters( 'regular_news_pro_filter_recent_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render recent section now.
        regular_news_pro_render_recent_section( $section_details );
    }
endif;

if ( ! function_exists( 'regular_news_pro_get_recent_section_details' ) ) :
    /**
    * recent section details.
    *
    * @since Regular News Pro 1.0.0
    * @param array $input recent section details.
    */
    function regular_news_pro_get_recent_section_details( $input ) {
        $options = regular_news_pro_get_theme_options();

       $tab_cats= ! empty( $options['recent_categories'] ) ? $options['recent_categories'] : array();

        $grid_cats = ! empty( $options['recent_grid_categories'] ) ? $options['recent_grid_categories'] : array();

        if ( empty( $tab_cats ) && empty( $grid_cats ) )
            return;

        $content = array();
        $content['tab'] = array();

        $i = 0;
        foreach ( $tab_cats as $cat_id ) :
            $content['tab'][$i] = array();
            $args = array(
                'post_type'         => 'post',
                'posts_per_page'    => 5,
                'cat'               => absint( $cat_id ),
                'ignore_sticky_posts'   => true,
                ); 

            // Run The Loop.
                $query = new WP_Query( $args );
                if ( $query->have_posts() ) : 
                    while ( $query->have_posts() ) : $query->the_post();
                        $tab_page_post[$i]['id']        = get_the_id();
                        $tab_page_post[$i]['title']     = get_the_title();
                        $tab_page_post[$i]['title_excerpt']     = substr( get_the_title(), 0, 80 );
                        $tab_page_post[$i]['url']       = get_the_permalink();
                        $tab_page_post[$i]['excerpt']   = regular_news_pro_trim_content( 25 );
                        $tab_page_post[$i]['auth_id']    = get_the_author_meta('ID');
                        $tab_page_post[$i]['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';


                        // Push to the main array.
                        array_push( $content['tab'][$i], $tab_page_post[$i] );
                    endwhile;
                endif;
                wp_reset_postdata();
                $i++;
            endforeach;

        $content['grid'] = array();

        $i = 0;
        foreach ( $grid_cats as $cat_id ) :
            $content['grid'][$i] = array();
            $args = array(
                'post_type'         => 'post',
                'posts_per_page'    => 5,
                'cat'               => absint( $cat_id ),
                'ignore_sticky_posts'   => true,
                ); 

            // Run The Loop.
                $query = new WP_Query( $args );
                if ( $query->have_posts() ) : 
                    while ( $query->have_posts() ) : $query->the_post();
                        $grid_page_post[$i]['id']        = get_the_id();
                        $grid_page_post[$i]['title_excerpt']     = substr( get_the_title(), 0, 30 );
                        $grid_page_post[$i]['url']       = get_the_permalink();
                        $grid_page_post[$i]['excerpt']   = regular_news_pro_trim_content( 25 );
                        $grid_page_post[$i]['auth_id']    = get_the_author_meta('ID');
                        $grid_page_post[$i]['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';


                        // Push to the main array.
                        array_push( $content['grid'][$i], $grid_page_post[$i] );
                    endwhile;
                endif;
                wp_reset_postdata();
                $i++;
            endforeach;
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent section content details.
add_filter( 'regular_news_pro_filter_recent_section_details', 'regular_news_pro_get_recent_section_details' );


if ( ! function_exists( 'regular_news_pro_render_recent_section' ) ) :
  /**
   * Start recent section
   *
   * @return string recent content
   * @since Regular News Pro 1.0.0
   *
   */
   function regular_news_pro_render_recent_section( $content_details = array() ) {
        $options = regular_news_pro_get_theme_options();
        $tab_cats= ! empty( $options['recent_categories'] ) ? $options['recent_categories'] : array();
        $grid_cats = ! empty( $options['recent_grid_categories'] ) ? $options['recent_grid_categories'] : array();

        if ( empty( $content_details ) ) {
            return;
        } ?>

         <div id="recent-posts" class="relative page-section">
                <div class="wrapper">
                    <div class="recent-wrapper clear <?php echo ( ! is_active_sidebar('recent-sidebar') ) ? 'blog-full-width' : ''; ?>">
                        <div class="section-header-wrapper">
                            <?php if ( ! empty( $options['recent_title'] ) ) : ?>
                                <div class="section-header">
                                    <h2 class="section-title"><?php echo esc_html( $options['recent_title'] ); ?></h2>
                                </div><!-- .section-header -->
                            <?php endif; ?>

                            <ul class="tabs">
                                <?php $i = 1; foreach (  $tab_cats as $cats) : ?>

                                <li data-tab="recent-<?php echo absint( $cats ); ?>" <?php echo ( $i == 1 ) ? 'class="active"' : ''; ?>> <?php echo esc_html( get_cat_name( $cats ) ); ?> </li>
                                <?php $i++; endforeach; ?>                                
                            </ul><!-- .tabs -->
                        </div><!-- .section-header-wrapper -->

                        <div class="section-content-wrapper col-2 clear">
                            <div class="recent-posts-tabs clear">
                                <?php $i=0; foreach ( $content_details['tab'] as $content_detail ) : ?>
                                    <div id="recent-<?php echo absint( $tab_cats[$i] ); ?>" class="tab-content <?php echo ( $i==0 ) ? 'active' : '' ; ?>">

                                        <?php $counter=0; foreach ( $content_detail as $content ) : ?>
                                            <article> 
                                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                                </div>

                                                <div class="entry-container">
                                                    <div class="entry-meta">
                                                        <?php  
                                                            echo regular_news_pro_author( $content['auth_id'] );
                                                            regular_news_pro_posted_on( $content['id'] );
                                                        ?>
                       
                                                    </div><!-- .entry-meta -->

                                                    <header class="entry-header">
                                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>" tabindex="0">

                                                            <?php
                                                            if($counter===0) {
                                                                echo esc_html( $content['title'] );
                                                            } else {
                                                               echo esc_html( $content['title_excerpt'] ); echo strlen( $content['title_excerpt'] ) > 79 ? '...' : '';
                                                            }
                                                            ?>

                                                        </a></h2>
                                                    </header>

                                                    <div class="entry-content">
                                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                                    </div>

                                                    <span class="cat-links">
                                                        <?php the_category( '', '', $content['id'] ); ?>
                                                    </span><!-- .cat-links --> 
                                                </div><!-- .entry-container -->
                                            </article>
                                        <?php $counter++; endforeach; ?>

                                    </div><!-- #gadegts -->
                                <?php $i++; endforeach; ?>
                            </div><!-- .recent-posts-tabs -->
                        </div><!-- .section-content -->

                        <div class="inner-wrapper">
                            <?php $i=0; foreach ( $content_details['grid'] as $content_detail ) : ?>
                                <div class="hentry">
                                    <div class="hentry-warpper">
                                        <?php $c=1; foreach ( $content_detail as $content ) : ?>
                                            <article>
                                                <?php if($c === 1 ) : ?>

                                                    <div class="entry-header">
                                                        <span>
                                                            <a href="<?php echo esc_url( get_category_link( $grid_cats[$i] ) ) ?>"><?php echo esc_html( get_cat_name( $grid_cats[$i] ) ); ?>
                                                            </a>
                                                        </span>
                                                    </div><!-- .section-header -->
                                                <?php endif; ?>

                                                <div class="featured-image" style="background-image:url('<?php echo esc_url( $content['image'] ); ?>')">
                                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                                    <div class="overlay"></div>
                                                </div>

                                                <div class="entry-container">
                                                    <div class="entry-meta">
                                                       <?php  
                                                            echo regular_news_pro_author( $content['auth_id'] );
                                                            regular_news_pro_posted_on( $content['id'] );
                                                        ?>
                                                    </div><!-- .entry-meta -->

                                                    <header class="entry-header">
                                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>" tabindex="-1"><?php echo esc_html( $content['title_excerpt'] ); echo strlen( $content['title_excerpt'] ) > 29 ? '...' : ''; ?></a></h2>
                                                    </header>
                                                </div>
                                            </article><!-- .hentry -->
                                        <?php $c++; endforeach;  ?>

                                    </div>  
                                </div><!-- .hentry -->
                            <?php $i++; endforeach;  ?>

                        </div>
                    </div><!-- .recent-wrapper -->

                    <?php  if ( is_active_sidebar('recent-sidebar') ) : ?>
                        <div class="recent-widget-wrapper">

                            <?php dynamic_sidebar('recent-sidebar'); ?>

                        </div><!-- .recent-reviews-wrapper -->
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #recent-posts -->
       
    <?php }
endif;